@@ -1,27 +1,13 @@
-/*=============================================================================
+/*
+    Copyright (C) 2011 Sebastian Pancratz
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2011 Sebastian Pancratz
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpq.h"
 
@@ -62,6 +48,12 @@ void _fmpq_pow_si(fmpz_t rnum, fmpz_t rden,
 
 void fmpq_pow_si(fmpq_t rop, const fmpq_t op, slong e)
 {
+    if (e < 0 && fmpz_is_zero(fmpq_numref(op)))
+    {
+        flint_printf("Exception (fmpq_pow_si). Division by zero.\n");
+        flint_abort();	
+    }
+    
     _fmpq_pow_si(fmpq_numref(rop), fmpq_denref(rop), 
                  fmpq_numref(op), fmpq_denref(op), e);
 }
