@@ -1,27 +1,13 @@
-/*=============================================================================
+/*
+    Copyright (C) 2009 William Hart
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2009 William Hart
- 
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #ifndef FMPZ_H
 #define FMPZ_H
@@ -45,6 +31,9 @@
 #include "nmod_vec.h"
 #include "fmpz-conversions.h"
 
+#if HAVE_PTHREAD
+#include <pthread.h>
+#endif
 
 #ifdef __cplusplus
  extern "C" {
@@ -62,11 +51,20 @@ typedef struct
 {
    mp_ptr dinv;
    slong n;
-   mp_bitcnt_t norm;
+   flint_bitcnt_t norm;
 } fmpz_preinvn_struct;
 
 typedef fmpz_preinvn_struct fmpz_preinvn_t[1];
 
+typedef struct
+{
+   int count;
+#if HAVE_PTHREAD
+   pthread_t thread;
+#endif
+   void * address;
+} fmpz_block_header_s;
+
 /* maximum positive value a small coefficient can have */
 #define COEFF_MAX ((WORD(1) << (FLINT_BITS - 2)) - WORD(1))
 
@@ -75,7 +73,7 @@ typedef fmpz_preinvn_struct fmpz_preinvn_t[1];
 
 #define COEFF_IS_MPZ(x) (((x) >> (FLINT_BITS - 2)) == WORD(1))  /* is x a pointer not an integer */
 
-__mpz_struct * _fmpz_new_mpz(void);
+FLINT_DLL __mpz_struct * _fmpz_new_mpz(void);
 
 FLINT_DLL void _fmpz_clear_mpz(fmpz f);
 
@@ -83,9 +81,9 @@ FLINT_DLL void _fmpz_cleanup_mpz_content(void);
 
 FLINT_DLL void _fmpz_cleanup(void);
 
-__mpz_struct * _fmpz_promote(fmpz_t f);
+FLINT_DLL __mpz_struct * _fmpz_promote(fmpz_t f);
 
-__mpz_struct * _fmpz_promote_val(fmpz_t f);
+FLINT_DLL __mpz_struct * _fmpz_promote_val(fmpz_t f);
 
 FMPZ_INLINE
 void _fmpz_demote(fmpz_t f)
@@ -169,27 +167,47 @@ void fmpz_init_set_si(fmpz_t f, slong g)
 FMPZ_INLINE
 void fmpz_clear(fmpz_t f)
 {
-	_fmpz_demote(f);
+    if (COEFF_IS_MPZ(*f))
+        _fmpz_clear_mpz(*f);
 }
 
-FLINT_DLL void fmpz_randbits(fmpz_t f, flint_rand_t state, mp_bitcnt_t bits);
+FLINT_DLL void fmpz_randbits(fmpz_t f, flint_rand_t state, flint_bitcnt_t bits);
 
 FLINT_DLL void fmpz_randm(fmpz_t f, flint_rand_t state, const fmpz_t m);
 
-FLINT_DLL void fmpz_randtest(fmpz_t f, flint_rand_t state, mp_bitcnt_t bits);
+FLINT_DLL void fmpz_randtest(fmpz_t f, flint_rand_t state, flint_bitcnt_t bits);
 
-FLINT_DLL void fmpz_randtest_unsigned(fmpz_t f, flint_rand_t state, mp_bitcnt_t bits);
+FLINT_DLL void fmpz_randtest_unsigned(fmpz_t f, flint_rand_t state, flint_bitcnt_t bits);
 
-FLINT_DLL void fmpz_randtest_not_zero(fmpz_t f, flint_rand_t state, mp_bitcnt_t bits);
+FLINT_DLL void fmpz_randtest_not_zero(fmpz_t f, flint_rand_t state, flint_bitcnt_t bits);
 
 FLINT_DLL void fmpz_randtest_mod(fmpz_t f, flint_rand_t state, const fmpz_t m);
 
 FLINT_DLL void fmpz_randtest_mod_signed(fmpz_t f, flint_rand_t state, const fmpz_t m);
 
+FLINT_DLL void fmpz_randprime(fmpz_t f, flint_rand_t state, 
+                              flint_bitcnt_t bits, int proved);
+
 FLINT_DLL slong fmpz_get_si(const fmpz_t f);
 
 FLINT_DLL ulong fmpz_get_ui(const fmpz_t f);
 
+FMPZ_INLINE void
+fmpz_get_uiui(mp_limb_t * hi, mp_limb_t * low, const fmpz_t f)
+{
+    if (!COEFF_IS_MPZ(*f))
+    {
+        *low = *f;
+        *hi  = 0;
+    }
+    else
+    {
+        __mpz_struct * mpz = COEFF_TO_PTR(*f);
+        *low = mpz->_mp_d[0];
+        *hi  = mpz->_mp_size == 2 ? mpz->_mp_d[1] : 0;
+    }
+}
+
 FMPZ_INLINE void
 fmpz_set_si(fmpz_t f, slong val)
 {
@@ -272,6 +290,14 @@ fmpz_neg_uiui(fmpz_t f, mp_limb_t hi, mp_limb_t lo)
     }
 }
 
+FLINT_DLL void fmpz_set_signed_uiui(fmpz_t r, ulong hi, ulong lo);
+
+FLINT_DLL void fmpz_set_signed_uiuiui(fmpz_t r, ulong hi, ulong mid, ulong lo);
+
+FLINT_DLL void fmpz_set_ui_array(fmpz_t out, const ulong * in, slong in_len);
+
+FLINT_DLL void fmpz_get_ui_array(ulong * out, slong out_len, const fmpz_t in);
+
 FLINT_DLL void fmpz_get_mpz(mpz_t x, const fmpz_t f);
 
 FLINT_DLL void fmpz_set_mpz(fmpz_t f, const mpz_t x);
@@ -286,6 +312,8 @@ FLINT_DLL void fmpz_set_mpf(fmpz_t f, const mpf_t x);
 
 FLINT_DLL void fmpz_get_mpfr(mpfr_t x, const fmpz_t f, mpfr_rnd_t rnd);
 
+FLINT_DLL int fmpz_get_mpn(mp_ptr *n, fmpz_t n_in);
+
 FLINT_DLL int fmpz_set_str(fmpz_t f, const char * str, int b);
 
 FLINT_DLL void flint_mpz_init_set_readonly(mpz_t z, const fmpz_t f);
@@ -358,7 +386,7 @@ FLINT_DLL size_t fmpz_out_raw( FILE *fout, const fmpz_t x );
 
 FLINT_DLL size_t fmpz_sizeinbase(const fmpz_t f, int b);
 
-char * fmpz_get_str(char * str, int b, const fmpz_t f);
+FLINT_DLL char * fmpz_get_str(char * str, int b, const fmpz_t f);
 
 FMPZ_INLINE
 void fmpz_swap(fmpz_t f, fmpz_t g)
@@ -409,9 +437,9 @@ FLINT_DLL mp_size_t fmpz_size(const fmpz_t f);
 
 FLINT_DLL int fmpz_sgn(const fmpz_t f);
 
-FLINT_DLL mp_bitcnt_t fmpz_bits(const fmpz_t f);
+FLINT_DLL flint_bitcnt_t fmpz_bits(const fmpz_t f);
 
-FLINT_DLL mp_bitcnt_t fmpz_val2(const fmpz_t x);
+FLINT_DLL flint_bitcnt_t fmpz_val2(const fmpz_t x);
 
 FMPZ_INLINE void
 fmpz_neg(fmpz_t f1, const fmpz_t f2)
@@ -425,8 +453,8 @@ fmpz_neg(fmpz_t f1, const fmpz_t f2)
     else                        /* coeff is large */
     {
         /* No need to retain value in promotion, as if aliased, both already large */
-        __mpz_struct *mpz_ptr = _fmpz_promote(f1);
-        mpz_neg(mpz_ptr, COEFF_TO_PTR(*f2));
+        __mpz_struct *mpz_res = _fmpz_promote(f1);
+        mpz_neg(mpz_res, COEFF_TO_PTR(*f2));
     }
 }
 
@@ -448,6 +476,22 @@ FLINT_DLL void fmpz_add_ui(fmpz_t f, const fmpz_t g, ulong x);
 
 FLINT_DLL void fmpz_sub_ui(fmpz_t f, const fmpz_t g, ulong x);
 
+FMPZ_INLINE void fmpz_add_si(fmpz_t f, const fmpz_t g, slong x)
+{
+    if (x >= 0)
+        fmpz_add_ui(f, g, (ulong) x);
+    else
+        fmpz_sub_ui(f, g, (ulong) -x);
+}
+
+FMPZ_INLINE void fmpz_sub_si(fmpz_t f, const fmpz_t g, slong x)
+{
+    if (x >= 0)
+        fmpz_sub_ui(f, g, (ulong) x);
+    else
+        fmpz_add_ui(f, g, (ulong) -x);
+}
+
 FLINT_DLL void fmpz_addmul_ui(fmpz_t f, const fmpz_t g, ulong x);
 
 FLINT_DLL void fmpz_submul_ui(fmpz_t f, const fmpz_t g, ulong x);
@@ -456,8 +500,14 @@ FLINT_DLL void fmpz_addmul(fmpz_t f, const fmpz_t g, const fmpz_t h);
 
 FLINT_DLL void fmpz_submul(fmpz_t f, const fmpz_t g, const fmpz_t h);
 
+FLINT_DLL void fmpz_fmma(fmpz_t f, const fmpz_t a, const fmpz_t b, const fmpz_t c, const fmpz_t d);
+
+FLINT_DLL void fmpz_fmms(fmpz_t f, const fmpz_t a, const fmpz_t b, const fmpz_t c, const fmpz_t d);
+
 FLINT_DLL void fmpz_pow_ui(fmpz_t f, const fmpz_t g, ulong exp);
 
+FLINT_DLL int fmpz_pow_fmpz(fmpz_t a, const fmpz_t b, const fmpz_t e);
+
 FLINT_DLL void fmpz_powm_ui(fmpz_t f, const fmpz_t g, ulong exp, const fmpz_t m);
 
 FLINT_DLL void fmpz_powm(fmpz_t f, const fmpz_t g, const fmpz_t e, const fmpz_t m);
@@ -478,7 +528,7 @@ FLINT_DLL void fmpz_or(fmpz_t r, const fmpz_t a, const fmpz_t b);
 
 FLINT_DLL void fmpz_xor(fmpz_t r, const fmpz_t a, const fmpz_t b);
 
-FLINT_DLL mp_bitcnt_t fmpz_popcnt(const fmpz_t c);
+FLINT_DLL flint_bitcnt_t fmpz_popcnt(const fmpz_t c);
 
 FLINT_DLL double fmpz_dlog(const fmpz_t x);
 FLINT_DLL slong fmpz_flog(const fmpz_t x, const fmpz_t b);
@@ -494,6 +544,8 @@ FLINT_DLL int fmpz_is_square(const fmpz_t f);
 
 FLINT_DLL void fmpz_root(fmpz_t r, const fmpz_t f, slong n);
 
+FLINT_DLL int fmpz_is_perfect_power(fmpz_t root, const fmpz_t f);
+
 FLINT_DLL void fmpz_sqrtrem(fmpz_t f, fmpz_t r, const fmpz_t g);
 
 FLINT_DLL ulong fmpz_fdiv_ui(const fmpz_t g, ulong h);
@@ -502,7 +554,7 @@ FLINT_DLL ulong fmpz_mod_ui(fmpz_t f, const fmpz_t g, ulong h);
 
 FLINT_DLL void fmpz_mod(fmpz_t f, const fmpz_t g, const fmpz_t h);
 
-void fmpz_mods(fmpz_t f, const fmpz_t g, const fmpz_t h);
+FLINT_DLL void fmpz_smod(fmpz_t f, const fmpz_t g, const fmpz_t h);
 
 FMPZ_INLINE void
 fmpz_negmod(fmpz_t r, const fmpz_t a, const fmpz_t mod)
@@ -528,6 +580,9 @@ FLINT_DLL int fmpz_invmod(fmpz_t f, const fmpz_t g, const fmpz_t h);
 
 FLINT_DLL int fmpz_jacobi(const fmpz_t a, const fmpz_t p);
 
+FLINT_DLL void fmpz_divides_mod_list(fmpz_t xstart, fmpz_t xstride,
+               fmpz_t xlength, const fmpz_t a, const fmpz_t b, const fmpz_t n);
+
 FLINT_DLL slong _fmpz_remove(fmpz_t x, const fmpz_t f, double finv);
 
 FLINT_DLL slong fmpz_remove(fmpz_t rop, const fmpz_t op, const fmpz_t f);
@@ -542,6 +597,8 @@ FLINT_DLL int fmpz_divisible(const fmpz_t f, const fmpz_t g);
 
 FLINT_DLL int fmpz_divisible_si(const fmpz_t f, slong g);
 
+FLINT_DLL void fmpz_cdiv_qr(fmpz_t f, fmpz_t s, const fmpz_t g, const fmpz_t h);
+
 FLINT_DLL void fmpz_cdiv_q(fmpz_t f, const fmpz_t g, const fmpz_t h);
 
 FLINT_DLL void fmpz_cdiv_q_si(fmpz_t f, const fmpz_t g, slong h);
@@ -550,6 +607,10 @@ FLINT_DLL void fmpz_cdiv_q_ui(fmpz_t f, const fmpz_t g, ulong h);
 
 FLINT_DLL void fmpz_cdiv_q_2exp(fmpz_t f, const fmpz_t g, ulong exp);
 
+FLINT_DLL void fmpz_cdiv_r_2exp(fmpz_t f, const fmpz_t g, ulong exp);
+
+FLINT_DLL ulong fmpz_cdiv_ui(const fmpz_t g, ulong h);
+
 FLINT_DLL void fmpz_fdiv_qr(fmpz_t f, fmpz_t s, const fmpz_t g, const fmpz_t h);
 
 FLINT_DLL void fmpz_fdiv_qr_preinvn(fmpz_t f, fmpz_t s, const fmpz_t g, 
@@ -575,16 +636,20 @@ FLINT_DLL void fmpz_tdiv_q_ui(fmpz_t f, const fmpz_t g, ulong h);
 
 FLINT_DLL void fmpz_tdiv_q_si(fmpz_t f, const fmpz_t g, slong h);
 
+FLINT_DLL void fmpz_tdiv_r_2exp(fmpz_t f, const fmpz_t g, ulong exp);
+
 FLINT_DLL ulong fmpz_tdiv_ui(const fmpz_t g, ulong h);
 
 FLINT_DLL void fmpz_tdiv_q_2exp(fmpz_t f, const fmpz_t g, ulong exp);
 
-FLINT_DLL void fmpz_preinvn_init(fmpz_preinvn_t inv, fmpz_t f);
+FLINT_DLL void fmpz_preinvn_init(fmpz_preinvn_t inv, const fmpz_t f);
 
 FLINT_DLL void fmpz_preinvn_clear(fmpz_preinvn_t inv);
 
 FLINT_DLL double fmpz_get_d_2exp(slong * exp, const fmpz_t f);
 
+FLINT_DLL void fmpz_set_d_2exp(fmpz_t f, double m, slong exp);
+
 FMPZ_INLINE void
 fmpz_mul2_uiui(fmpz_t f, const fmpz_t g, ulong h1, ulong h2)
 {
@@ -635,23 +700,21 @@ FLINT_DLL void fmpz_rfac_ui(fmpz_t r, const fmpz_t x, ulong n);
 
 FLINT_DLL void fmpz_rfac_uiui(fmpz_t r, ulong x, ulong n);
 
-FLINT_DLL int fmpz_bit_pack(mp_ptr arr, mp_bitcnt_t shift, mp_bitcnt_t bits, 
+FLINT_DLL int fmpz_bit_pack(mp_ptr arr, flint_bitcnt_t shift, flint_bitcnt_t bits, 
                   const fmpz_t coeff, int negate, int borrow);
 
-FLINT_DLL int fmpz_bit_unpack(fmpz_t coeff, mp_srcptr arr, mp_bitcnt_t shift, 
-                    mp_bitcnt_t bits, int negate, int borrow);
+FLINT_DLL int fmpz_bit_unpack(fmpz_t coeff, mp_srcptr arr, flint_bitcnt_t shift, 
+                    flint_bitcnt_t bits, int negate, int borrow);
 
 FLINT_DLL void fmpz_bit_unpack_unsigned(fmpz_t coeff, mp_srcptr arr, 
-                              mp_bitcnt_t shift, mp_bitcnt_t bits);
+                              flint_bitcnt_t shift, flint_bitcnt_t bits);
+
+/* crt ***********************************************************************/
 
 FLINT_DLL void _fmpz_CRT_ui_precomp(fmpz_t out, const fmpz_t r1, const fmpz_t m1,
     ulong r2, ulong m2, mp_limb_t m2inv, const fmpz_t m1m2, mp_limb_t c,
         int sign);
 
-FLINT_DLL void _fmpz_CRT_ui_signed_precomp(fmpz_t out, const fmpz_t r1,
-        const fmpz_t m1, ulong r2, ulong m2, mp_limb_t m2inv, const fmpz_t m1m2,
-        const fmpz_t halfm1m2, mp_limb_t c);
-
 FLINT_DLL void fmpz_CRT_ui(fmpz_t out, const fmpz_t r1, const fmpz_t m1,
     ulong r2, ulong m2, int sign);
 
@@ -703,6 +766,61 @@ FMPZ_INLINE void fmpz_set_ui_smod(fmpz_t f, mp_limb_t x, mp_limb_t m)
         fmpz_set_si(f, x - m);
 }
 
+/* instructions do A = B + I*(C - B) mod M */
+typedef struct
+{
+    slong a_idx; /* index of A */
+    slong b_idx; /* index of B */
+    slong c_idx; /* index of C */
+    fmpz_t idem;     /* I */
+    fmpz_t modulus;  /* M */
+} _fmpz_multi_crt_prog_instr;
+
+typedef struct
+{
+    _fmpz_multi_crt_prog_instr * prog; /* straight line program */
+    slong length; /* length of prog */
+    slong alloc;  /* alloc of prog */
+    slong localsize; /* length of outputs required in nmod_poly_crt_run */
+    slong temp1loc; /* index of temporary used in run */
+    slong temp2loc; /* index of another tempory used in run */
+    int good;   /* the moduli are good for CRT, essentially relatively prime */
+} fmpz_multi_crt_struct;
+
+typedef fmpz_multi_crt_struct fmpz_multi_crt_t[1];
+
+FLINT_DLL void fmpz_multi_crt_init(fmpz_multi_crt_t CRT);
+
+FLINT_DLL int fmpz_multi_crt_precompute(fmpz_multi_crt_t CRT,
+                                               const fmpz * moduli, slong len);
+
+FLINT_DLL int fmpz_multi_crt_precompute_p(fmpz_multi_crt_t CRT,
+                                       const fmpz * const * moduli, slong len);
+
+FLINT_DLL void fmpz_multi_crt_precomp(fmpz_t output, const fmpz_multi_crt_t P,
+                                                          const fmpz * inputs);
+
+FLINT_DLL void fmpz_multi_crt_precomp_p(fmpz_t output,
+                        const fmpz_multi_crt_t P, const fmpz * const * inputs);
+
+FLINT_DLL int fmpz_multi_crt(fmpz_t output, const fmpz * moduli,
+                                               const fmpz * values, slong len);
+
+FLINT_DLL void fmpz_multi_crt_clear(fmpz_multi_crt_t P);
+
+FMPZ_INLINE slong _fmpz_multi_crt_local_size(const fmpz_multi_crt_t CRT)
+{
+    return CRT->localsize;
+}
+
+FLINT_DLL void _fmpz_multi_crt_run(fmpz * outputs, const fmpz_multi_crt_t CRT,
+                                                          const fmpz * inputs);
+
+FLINT_DLL void _fmpz_multi_crt_run_p(fmpz * outputs,
+                      const fmpz_multi_crt_t CRT, const fmpz * const * inputs);
+
+/*****************************************************************************/
+
 FLINT_DLL mp_limb_t fmpz_abs_ubound_ui_2exp(slong * exp, const fmpz_t x, int bits);
 
 FLINT_DLL mp_limb_t fmpz_abs_lbound_ui_2exp(slong * exp, const fmpz_t x, int bits);
@@ -759,6 +877,8 @@ FLINT_DLL int fmpz_is_prime(const fmpz_t p);
 FLINT_DLL int fmpz_divisor_in_residue_class_lenstra(fmpz_t fac, const fmpz_t n, 
                                                const fmpz_t r, const fmpz_t s);
 
+FLINT_DLL void fmpz_nextprime(fmpz_t res, const fmpz_t n, int proved);
+
 /* Primorials */
 
 FLINT_DLL void fmpz_primorial(fmpz_t res, ulong n);
@@ -771,6 +891,34 @@ FLINT_DLL int fmpz_moebius_mu(const fmpz_t n);
 
 FLINT_DLL void fmpz_divisor_sigma(fmpz_t res, const fmpz_t n, ulong k);
 
+/* Functions that should be in ulong extras */
+
+FLINT_DLL ulong n_powmod2_fmpz_preinv(ulong a, const fmpz_t exp,
+                                                          ulong n, ulong ninv);
+
+FMPZ_INLINE mp_limb_t nmod_pow_fmpz(mp_limb_t a, const fmpz_t exp, nmod_t mod)
+{
+    return n_powmod2_fmpz_preinv(a, exp, mod.n, mod.ninv);
+}
+
+/* Inlines *******************************************************************/
+
+FLINT_DLL fmpz * __new_fmpz();
+FLINT_DLL void __free_fmpz(fmpz * f);
+FLINT_DLL void __fmpz_set_si(fmpz_t f, slong val);
+FLINT_DLL void __fmpz_set_ui(fmpz_t f, ulong val);
+FLINT_DLL void __fmpz_init(fmpz_t f);
+FLINT_DLL void __fmpz_init_set_ui(fmpz_t f, ulong g);
+FLINT_DLL void __fmpz_clear(fmpz_t f);
+FLINT_DLL int __fmpz_lt(fmpz_t f, fmpz_t g);
+FLINT_DLL int __fmpz_gt(fmpz_t f, fmpz_t g);
+FLINT_DLL int __fmpz_lte(fmpz_t f, fmpz_t g);
+FLINT_DLL int __fmpz_gte(fmpz_t f, fmpz_t g);
+FLINT_DLL int __fmpz_eq(fmpz_t f, fmpz_t g);
+FLINT_DLL int __fmpz_neq(fmpz_t f, fmpz_t g);
+FLINT_DLL void __fmpz_init_set(fmpz_t f, const fmpz_t g);
+FLINT_DLL void __fmpz_neg(fmpz_t f1, const fmpz_t f2);
+
 #ifdef __cplusplus
 }
 #endif
