@@ -1,10 +1,21 @@
+/*
+    Copyright (C) 2012 Thomas M. DuBuisson
+
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
+
 #include <gmp.h>
 #include "flint.h"
 #include "ulong_extras.h"
 #include "fmpz.h"
 
 #ifdef POPCNT_INTRINSICS
-static __inline__ mp_bitcnt_t shortCount(slong val)
+static __inline__ flint_bitcnt_t shortCount(slong val)
 {
 #if defined(_WIN64) || defined(__mips64)
    return __builtin_popcountll(val);  
@@ -15,9 +26,9 @@ static __inline__ mp_bitcnt_t shortCount(slong val)
 #else
 /* A naive implementation if neither your processor nor your compiler want to
  * do the work. */
-static __inline__ mp_bitcnt_t shortCount(slong val)
+static __inline__ flint_bitcnt_t shortCount(slong val)
 {
-        mp_bitcnt_t cnt;
+        flint_bitcnt_t cnt;
         for(cnt=0; val; val >>= 1) {
                 cnt += val & 1;
         }
@@ -25,7 +36,7 @@ static __inline__ mp_bitcnt_t shortCount(slong val)
 }
 #endif
 
-mp_bitcnt_t fmpz_popcnt(const fmpz_t c)
+flint_bitcnt_t fmpz_popcnt(const fmpz_t c)
 {
         fmpz c1;
         c1 = *c;
