@@ -1,29 +1,15 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2009, 2010 William Hart
     Copyright (C) 2009, 2010 Andy Novocin
     Copyright (C) 2014 Abhinav Baid
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpz_lll.h"
 #ifdef GM
@@ -36,7 +22,7 @@ fmpz_lll_check_babai_heuristic(int kappa, fmpz_mat_t B, fmpz_mat_t U,
                                mpf_mat_t mu, mpf_mat_t r, mpf * s,
                                mpf_mat_t appB, fmpz_gram_t A, int a, int zeros,
                                int kappamax, int n, mpf_t tmp, mpf_t rtmp,
-                               mp_bitcnt_t prec, const fmpz_lll_t fl)
+                               flint_bitcnt_t prec, const fmpz_lll_t fl)
 {
     if (fl->rt == Z_BASIS && fl->gt == APPROX)
     {
@@ -117,7 +103,7 @@ fmpz_lll_check_babai_heuristic(int kappa, fmpz_mat_t B, fmpz_mat_t U,
                 for (j = 0; j < kappa; j++)
                 {
                     slong expo2;
-                    mpf_get_d_2exp(&expo2, mpf_mat_entry(mu, kappa, j));
+                    flint_mpf_get_d_2exp(&expo2, mpf_mat_entry(mu, kappa, j));
                     new_max_expo = FLINT_MAX(new_max_expo, expo2);
                 }
                 if (new_max_expo > max_expo - SIZE_RED_FAILURE_THRESH)
@@ -201,7 +187,7 @@ fmpz_lll_check_babai_heuristic(int kappa, fmpz_mat_t B, fmpz_mat_t U,
                                     mpf_mat_entry(mu, kappa, k), rtmp);
                         }
 
-                        mpf_get_d_2exp(&exponent, tmp);
+                        flint_mpf_get_d_2exp(&exponent, tmp);
                         if (exponent < CPU_SIZE_1 - 2)
                         {
                             /* X is stored in an slong */
@@ -333,7 +319,7 @@ fmpz_lll_check_babai_heuristic(int kappa, fmpz_mat_t B, fmpz_mat_t U,
                 for (j = 0; j < kappa; j++)
                 {
                     slong expo2;
-                    mpf_get_d_2exp(&expo2, mpf_mat_entry(mu, kappa, j));
+                    flint_mpf_get_d_2exp(&expo2, mpf_mat_entry(mu, kappa, j));
                     new_max_expo = FLINT_MAX(new_max_expo, expo2);
                 }
                 if (new_max_expo > max_expo - SIZE_RED_FAILURE_THRESH)
@@ -385,7 +371,7 @@ fmpz_lll_check_babai_heuristic(int kappa, fmpz_mat_t B, fmpz_mat_t U,
                         }
                         else    /* otherwise X is -1 */
                         {
-                            fmpz_set_si(x + j, -1);
+                            fmpz_set_si(x + j, -WORD(1));
                             for (k = zeros + 1; k < j; k++)
                             {
                                 mpf_add(mpf_mat_entry(mu, kappa, k),
@@ -426,7 +412,7 @@ fmpz_lll_check_babai_heuristic(int kappa, fmpz_mat_t B, fmpz_mat_t U,
                                     mpf_mat_entry(mu, kappa, k), rtmp);
                         }
 
-                        mpf_get_d_2exp(&exponent, tmp);
+                        flint_mpf_get_d_2exp(&exponent, tmp);
                         if (exponent < CPU_SIZE_1 - 2)
                         {
                             /* X is stored in an slong */
