@@ -1,29 +1,15 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2009, 2010 William Hart
     Copyright (C) 2009, 2010 Andy Novocin
     Copyright (C) 2014 Abhinav Baid
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpz_lll.h"
 
@@ -79,7 +65,7 @@ FUNC_HEAD
             {
                 flint_printf
                     ("Exception (fmpz_lll_d*). Incompatible dimensions of capturing matrix.\n");
-                abort();
+                flint_abort();
             }
         }
 
@@ -246,7 +232,7 @@ FUNC_HEAD
                         2 * d_mat_entry(mu, kappa,
                                         kappa - 1) * d_mat_entry(r, kappa,
                                                                  kappa - 1);
-                    fmpz_set_d(rii, ldexp(s[kappa - 1] - tmp, 2 * expo[kappa]));    /* using a heuristic lower bound on the final GS norm */
+                    fmpz_set_d_2exp(rii, s[kappa - 1] - tmp, 2 * expo[kappa]);    /* using a heuristic lower bound on the final GS norm */
                     if (fmpz_cmp(rii, gs_B) > 0)
                     {
                         d--;
@@ -381,7 +367,7 @@ FUNC_HEAD
             for (i = d - 1; (i >= 0) && (ok > 0); i--)
             {
                 /* rii is the G-S length of ith vector divided by 2 */
-                fmpz_set_d(rii, ldexp(d_mat_entry(r, i, i), 2 * expo[i] - 1));
+                fmpz_set_d_2exp(rii, d_mat_entry(r, i, i), 2 * expo[i] - 1);
                 if ((ok = fmpz_cmp(rii, gs_B)) > 0)
                 {
                     newd--;
@@ -441,7 +427,7 @@ FUNC_HEAD
             {
                 flint_printf
                     ("Exception (fmpz_lll_d*). Incompatible dimensions of capturing matrix.\n");
-                abort();
+                flint_abort();
             }
             else if (U->c == d && n > d && fmpz_mat_is_one(U))
             {
