@@ -1,27 +1,13 @@
-/*=============================================================================
+/*
+    Copyright (C) 2014 Abhinav Baid
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2014 Abhinav Baid
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpz_lll.h"
 #include "mpfr_vec.h"
@@ -29,7 +15,7 @@
 
 int
 fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
-                         mp_bitcnt_t prec)
+                         flint_bitcnt_t prec)
 {
     if (fl->rt == Z_BASIS)
     {
@@ -37,7 +23,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
         slong i, j, k, m, n;
         mpfr_mat_t A, Q, R, V, Wu, Wd, bound, bound2, bound3, boundt, mm, rm,
             mn, rn, absR;
-        mpfr *du, *dd;
+        flint_mpfr *du, *dd;
         mpfr_t s, norm, ti, tj, tmp;
 
         if (B->r == 0 || B->r == 1)
@@ -123,7 +109,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
                              norm, MPFR_RNDN);
                 }
                 mpfr_mul_si(mpfr_mat_entry(V, j, i), mpfr_mat_entry(V, j, i),
-                            -1, MPFR_RNDN);
+                            -WORD(1), MPFR_RNDN);
                 mpfr_mul(mpfr_mat_entry(V, j, i), mpfr_mat_entry(V, j, i),
                          mpfr_mat_entry(V, j, j), MPFR_RNDN);
             }
@@ -522,7 +508,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
         slong i, j, k, m, n;
         mpfr_mat_t A, R, V, Wu, Wd, bound, bound2, bound3, boundt, mm, rm,
             mn, rn, absR;
-        mpfr *du, *dd;
+        flint_mpfr *du, *dd;
         mpfr_t s, norm, ti, tj, tmp;
 
         if (B->r == 0 || B->r == 1)
@@ -591,7 +577,7 @@ fmpz_lll_is_reduced_mpfr(const fmpz_mat_t B, const fmpz_lll_t fl,
                              norm, MPFR_RNDN);
                 }
                 mpfr_mul_si(mpfr_mat_entry(V, j, i), mpfr_mat_entry(V, j, i),
-                            -1, MPFR_RNDN);
+                            -WORD(1), MPFR_RNDN);
                 mpfr_mul(mpfr_mat_entry(V, j, i), mpfr_mat_entry(V, j, i),
                          mpfr_mat_entry(V, j, j), MPFR_RNDN);
             }
