@@ -1,29 +1,15 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2009, 2010 William Hart
     Copyright (C) 2009, 2010 Andy Novocin
     Copyright (C) 2014 Abhinav Baid
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpz_lll.h"
 
@@ -71,7 +57,7 @@ FUNC_HEAD
             {
                 flint_printf
                     ("Exception (fmpz_lll_mpf*). Incompatible dimensions of capturing matrix.\n");
-                abort();
+                flint_abort();
             }
         }
 
@@ -368,7 +354,7 @@ FUNC_HEAD
             {
                 flint_printf
                     ("Exception (fmpz_lll_mpf*). Incompatible dimensions of capturing matrix.\n");
-                abort();
+                flint_abort();
             }
             else if (U->c == d && n > d && fmpz_mat_is_one(U))
             {
