@@ -1,34 +1,20 @@
-/*=============================================================================
+/*
+    Copyright (C) 2014, 2015 Alex J. Best
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2014 Alex J. Best
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpz_mat.h"
 #include "fmpq_mat.h"
 #include "perm.h"
 
 static void
-add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
+add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1, flint_rand_t state)
 {
     int neg;
     slong i, j, n, bits;
@@ -36,7 +22,6 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
     fmpq_t num, alpha;
     fmpz_mat_t Bu, B1, cols, k;
     fmpq_mat_t H1_q, cols_q, x;
-    flint_rand_t state;
 
     n = B->r;
 
@@ -64,8 +49,8 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
     if (fmpz_mat_nullspace(k, B1) != 1)
     {
         flint_printf("Exception (fmpz_mat_hnf_pernet_stein). "
-                     "Nullspace was not dimension one.\n");
-        abort();
+                "Nullspace was not dimension one.\n");
+        flint_abort();
     }
 
     bits = fmpz_mat_max_bits(B1);
@@ -77,7 +62,6 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
     fmpz_init(tmp);
 
     /* set the last row of Bu to be random, such that Bu is nonsingular */
-    flint_randinit(state);
     while (fmpz_is_zero(tmp))
     {
         _fmpz_vec_randtest(Bu->rows[n - 1], state, n, bits);
@@ -85,9 +69,8 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
         fmpz_zero(tmp);
         for (j = 0; j < n; j++)
             fmpz_addmul(tmp, fmpz_mat_entry(Bu, n - 1, j),
-                        fmpz_mat_entry(k, j, 0));
+                    fmpz_mat_entry(k, j, 0));
     }
-    flint_randclear(state);
     fmpz_clear(tmp);
 
     /* solve Bu*x = cols */
@@ -95,7 +78,7 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
     {
         flint_printf("Exception (fmpz_mat_hnf_pernet_stein). "
                 "Singular input matrix for solve.");
-        abort();
+        flint_abort();
     }
 
     /* fix final row */
@@ -118,16 +101,16 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
         for (i = 0; i < n; i++)
         {
             _fmpq_addmul(fmpq_numref(num), fmpq_denref(num),
-                         fmpz_mat_entry(B, n - 1, i), one,
-                         fmpq_mat_entry_num(x, i, j),
-                         fmpq_mat_entry_den(x, i, j));
+                    fmpz_mat_entry(B, n - 1, i), one,
+                    fmpq_mat_entry_num(x, i, j),
+                    fmpq_mat_entry_den(x, i, j));
         }
         _fmpq_sub(fmpq_numref(alpha), fmpq_denref(alpha),
-                  fmpz_mat_entry(B, n - 1, n + j), one,
-                  fmpq_numref(num), fmpq_denref(num));
+                fmpz_mat_entry(B, n - 1, n + j), one,
+                fmpq_numref(num), fmpq_denref(num));
 
         _fmpq_mul(fmpq_numref(alpha), fmpq_denref(alpha),
-                  fmpq_numref(alpha), fmpq_denref(alpha), one, den);
+                fmpq_numref(alpha), fmpq_denref(alpha), one, den);
         if (neg)
             fmpq_neg(alpha, alpha);
 
@@ -135,8 +118,8 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
         for (i = 0; i < n; i++)
         {
             _fmpq_addmul(fmpq_mat_entry_num(x, i, j),
-                         fmpq_mat_entry_den(x, i, j), fmpq_numref(alpha),
-                         fmpq_denref(alpha), fmpz_mat_entry(k, i, 0), one);
+                    fmpq_mat_entry_den(x, i, j), fmpq_numref(alpha),
+                    fmpq_denref(alpha), fmpz_mat_entry(k, i, 0), one);
         }
     }
 
@@ -167,10 +150,9 @@ add_columns(fmpz_mat_t H, const fmpz_mat_t B, const fmpz_mat_t H1)
 
 /* takes input matrix H with rows 0 to start_row - 1 in HNF to a HNF matrix */
 static void
-add_rows(fmpz_mat_t H, slong start_row)
+add_rows(fmpz_mat_t H, slong start_row, slong *pivots, slong num_pivots)
 {
-    slong i, i2, j, j2, num_pivots, new_row, row;
-    slong *pivots;
+    slong i, i2, j, j2, new_row, row;
     fmpz_t b, d, u, v, r1d, r2d, q;
 
     fmpz_init(b);
@@ -180,29 +162,22 @@ add_rows(fmpz_mat_t H, slong start_row)
     fmpz_init(r1d);
     fmpz_init(r2d);
     fmpz_init(q);
-    num_pivots = 0;
-
-    /* find the pivots of H */
-    pivots = flint_malloc(H->c * sizeof(slong));
-    for (i = j = 0; i < start_row; i++, j++)
-    {
-        for (; j < H->c && fmpz_is_zero(fmpz_mat_entry(H, i, j)); j++) ;
-        if (j == H->c)
-            break;
-        pivots[i] = j;
-        num_pivots = i + 1;
-    }
 
     for (row = start_row; row < H->r; row++)
     {
         /* reduce row to be added with existing */
-        for (i = 0; i < num_pivots; i++)
+        for (i = j = 0; i < num_pivots; i++)
         {
-            j = pivots[i];
+            /* check if added row can still be reduced */
+            for (; j < pivots[i]; j++)
+                if (!fmpz_is_zero(fmpz_mat_entry(H, row, j)))
+                    break;
+            if (j < pivots[i])
+                break;
             if (fmpz_is_zero(fmpz_mat_entry(H, row, j)))
                 continue;
             fmpz_xgcd(d, u, v, fmpz_mat_entry(H, i, j),
-                      fmpz_mat_entry(H, row, j));
+                    fmpz_mat_entry(H, row, j));
             fmpz_divexact(r1d, fmpz_mat_entry(H, i, j), d);
             fmpz_divexact(r2d, fmpz_mat_entry(H, row, j), d);
             for (j2 = j; j2 < H->c; j2++)
@@ -210,12 +185,13 @@ add_rows(fmpz_mat_t H, slong start_row)
                 fmpz_mul(b, u, fmpz_mat_entry(H, i, j2));
                 fmpz_addmul(b, v, fmpz_mat_entry(H, row, j2));
                 fmpz_mul(fmpz_mat_entry(H, row, j2), r1d,
-                         fmpz_mat_entry(H, row, j2));
+                        fmpz_mat_entry(H, row, j2));
                 fmpz_submul(fmpz_mat_entry(H, row, j2), r2d,
-                            fmpz_mat_entry(H, i, j2));
+                        fmpz_mat_entry(H, i, j2));
                 fmpz_set(fmpz_mat_entry(H, i, j2), b);
             }
         }
+
         /* find first non-zero entry of the added row */
         for (j = 0; j < H->c && fmpz_is_zero(fmpz_mat_entry(H, row, j)); j++) ;
         new_row = row;
@@ -226,21 +202,24 @@ add_rows(fmpz_mat_t H, slong start_row)
                 for (j2 = j; j2 < H->c; j2++)
                 {
                     fmpz_neg(fmpz_mat_entry(H, row, j2),
-                             fmpz_mat_entry(H, row, j2));
+                            fmpz_mat_entry(H, row, j2));
                 }
             }
             do
             {
                 if (new_row < row)
                     fmpz_mat_swap_rows(H, NULL, new_row, new_row + 1);
+                if (new_row == 0)
+                    break;
                 new_row--;
                 for (j2 = 0; j2 < H->c &&
-                     fmpz_is_zero(fmpz_mat_entry(H, new_row, j2)); j2++) ;
+                        fmpz_is_zero(fmpz_mat_entry(H, new_row, j2)); j2++) ;
             }
             while (j2 > j);
         }
 
-        for (i = new_row, j = 0; i <= row; i++, j++)
+        /* recompute pivots */
+        for (i = new_row, j = 0; i <= row && i < H->c; i++, j++)
         {
             for (; j < H->c && fmpz_is_zero(fmpz_mat_entry(H, i, j)); j++) ;
             if (j == H->c)
@@ -255,11 +234,11 @@ add_rows(fmpz_mat_t H, slong start_row)
             for (i2 = 0; i2 < i; i2++)
             {
                 fmpz_fdiv_q(q, fmpz_mat_entry(H, i2, pivots[i]),
-                            fmpz_mat_entry(H, i, pivots[i]));
+                        fmpz_mat_entry(H, i, pivots[i]));
                 for (j2 = pivots[i]; j2 < H->c; j2++)
                 {
                     fmpz_submul(fmpz_mat_entry(H, i2, j2), q,
-                                fmpz_mat_entry(H, i, j2));
+                            fmpz_mat_entry(H, i, j2));
                 }
             }
         }
@@ -272,12 +251,11 @@ add_rows(fmpz_mat_t H, slong start_row)
     fmpz_clear(u);
     fmpz_clear(d);
     fmpz_clear(b);
-    flint_free(pivots);
 }
 
 static void
 double_det(fmpz_t d1, fmpz_t d2, const fmpz_mat_t B, const fmpz_mat_t c,
-           const fmpz_mat_t d)
+        const fmpz_mat_t d)
 {
     slong i, j, n;
     slong *P;
@@ -325,7 +303,7 @@ double_det(fmpz_t d1, fmpz_t d2, const fmpz_mat_t B, const fmpz_mat_t c,
         {
             fmpz_lcm(u1, u1, fmpq_mat_entry_den(x, i, 0));
             fmpq_div(tmpq, fmpq_mat_entry(x, i, 0),
-                     fmpq_mat_entry(x, n - 1, 0));
+                    fmpq_mat_entry(x, n - 1, 0));
             fmpz_lcm(u2, u2, fmpq_denref(tmpq));
         }
         fmpz_lcm(u1, u1, fmpq_mat_entry_den(x, n - 1, 0));
@@ -340,7 +318,7 @@ double_det(fmpz_t d1, fmpz_t d2, const fmpz_mat_t B, const fmpz_mat_t c,
             fmpz_zero(s1);
             for (i = 0; i < n; i++)
                 fmpz_addmul(s1, fmpz_mat_entry(Bt, i, j),
-                            fmpz_mat_entry(Bt, i, j));
+                        fmpz_mat_entry(Bt, i, j));
             fmpz_sqrtrem(s1, t, s1);
             if (!fmpz_is_zero(t))
                 fmpz_add_ui(s1, s1, UWORD(1));
@@ -394,7 +372,7 @@ double_det(fmpz_t d1, fmpz_t d2, const fmpz_mat_t B, const fmpz_mat_t c,
             v1mod = UWORD(1);
             for (i = 0; i < n; i++)
                 v1mod = n_mulmod2_preinv(v1mod, nmod_mat_entry(Btmod, i, i), p,
-                                         Btmod->mod.ninv);
+                        Btmod->mod.ninv);
             if (_perm_parity(P, n) == 1)
                 v1mod = nmod_neg(v1mod, Btmod->mod);
 
@@ -410,14 +388,14 @@ double_det(fmpz_t d1, fmpz_t d2, const fmpz_mat_t B, const fmpz_mat_t c,
             v2mod = UWORD(1);
             for (i = 0; i < n; i++)
                 v2mod = n_mulmod2_preinv(v2mod, nmod_mat_entry(Btmod, i, i), p,
-                                         Btmod->mod.ninv);
+                        Btmod->mod.ninv);
             if (_perm_parity(P, n) == 1)
                 v2mod = nmod_neg(v2mod, Btmod->mod);
 
             v1mod = n_mulmod2_preinv(v1mod, n_invmod(u1mod, p), p,
-                                     Btmod->mod.ninv);
+                    Btmod->mod.ninv);
             v2mod = n_mulmod2_preinv(v2mod, n_invmod(u2mod, p), p,
-                                     Btmod->mod.ninv);
+                    Btmod->mod.ninv);
             fmpz_CRT_ui(v1, v1, prod, v1mod, p, 1);
             fmpz_CRT_ui(v2, v2, prod, v2mod, p, 1);
             fmpz_mul_ui(prod, prod, p);
@@ -451,10 +429,10 @@ double_det(fmpz_t d1, fmpz_t d2, const fmpz_mat_t B, const fmpz_mat_t c,
     fmpq_mat_clear(x);
 }
 
-int
+void
 fmpz_mat_hnf_pernet_stein(fmpz_mat_t H, const fmpz_mat_t A, flint_rand_t state)
 {
-    slong i, j, m, n, p, r, *P, *pivots;
+    slong i, j, m, n, p, r, *P, *pivots, finished;
     fmpz_t d1, d2, g, s, t;
     fmpz_mat_t c, d, B, C, H1, H2, H3;
     nmod_mat_t Amod;
@@ -462,167 +440,195 @@ fmpz_mat_hnf_pernet_stein(fmpz_mat_t H, const fmpz_mat_t A, flint_rand_t state)
     m = fmpz_mat_nrows(A);
     n = fmpz_mat_ncols(A);
 
+    if (m == 0 || n == 0)
+        return;
+
     /* find permutation so we can ensure first rows of H are nonsingular */
     P = _perm_init(m);
     pivots = _perm_init(n);
-    
-    p = n_randprime(state, NMOD_MAT_OPTIMAL_MODULUS_BITS, 1);
-    nmod_mat_init(Amod, m, n, p);
 
-    fmpz_mat_get_nmod_mat(Amod, A);
-    r = _nmod_mat_rref(Amod, pivots, P);
+    finished = 0;
 
-    nmod_mat_clear(Amod);
-
-    /* rank is not full, so silently fail */
-    if (r < FLINT_MIN(m, n))
+    while (!finished)
     {
-        _perm_clear(P);
-        _perm_clear(pivots);
-        
-        return 0;
-    }
+        p = n_randprime(state, NMOD_MAT_OPTIMAL_MODULUS_BITS, 1);
+        nmod_mat_init(Amod, m, n, p);
 
-    /* if A has full column rank we might wish to use minors based hnf */
-    if (r == n && n < 52)
-    {
-        slong b = fmpz_mat_max_bits(A), cutoff = 52;
-        if (b < 0)
-            b = -b;
+        fmpz_mat_get_nmod_mat(Amod, A);
+        r = _nmod_mat_rref(Amod, pivots, P);
 
-        if (b <= 8)
-            cutoff = 35;
-        else if (b <= 32)
-            cutoff = 44;
-        else if (b <= 256)
-            cutoff = 48;
+        nmod_mat_clear(Amod);
 
-        if (n < cutoff)
+        /* rank is zero so matrix is possibly zero too */
+        if (r == 0)
         {
-            fmpz_mat_hnf_minors(H, A);
-            _perm_clear(P);
-            _perm_clear(pivots);
-            return 1;
-        }
-    }
-
-    fmpz_mat_init(c, 1, r - 1);
-    fmpz_mat_init(d, 1, r - 1);
-    fmpz_mat_init(B, r - 2, r - 1);
-    fmpz_mat_init(C, r - 1, r - 1);
-
-    for (i = 0; i < r - 2; i++)
-    {
-        for (j = 0; j < r - 1; j++)
-        {
-            fmpz_set(fmpz_mat_entry(B, i, j),
-                     fmpz_mat_entry(A, P[i], pivots[j]));
-            fmpz_set(fmpz_mat_entry(C, i, j),
-                     fmpz_mat_entry(A, P[i], pivots[j]));
-        }
-        fmpz_set(fmpz_mat_entry(C, i, r - 1),
-                 fmpz_mat_entry(A, P[i], pivots[r - 1]));
-    }
-    for (j = 0; j < r - 1; j++)
-    {
-        fmpz_set(fmpz_mat_entry(c, 0, j),
-                 fmpz_mat_entry(A, P[r - 2], pivots[j]));
-        fmpz_set(fmpz_mat_entry(d, 0, j),
-                 fmpz_mat_entry(A, P[r - 1], pivots[j]));
-    }
-
-    fmpz_init(g);
-    fmpz_init(s);
-    fmpz_init(t);
-
-    /* if rank is too low leave g = 0 so we don't try to decompose later */
-    if (r > 2)
-    {
-        fmpz_init(d1);
-        fmpz_init(d2);
-
-        double_det(d1, d2, B, c, d);
-        fmpz_xgcd(g, s, t, d1, d2);
-
-        for (j = 0; j < r - 1; j++)
-        {
-            fmpz_mul(fmpz_mat_entry(C, r - 2, j), s,
-                     fmpz_mat_entry(A, P[r - 2], pivots[j]));
-            fmpz_addmul(fmpz_mat_entry(C, r - 2, j), t,
-                        fmpz_mat_entry(A, P[r - 1], pivots[j]));
+            if (fmpz_mat_is_zero(A))
+            {
+                fmpz_mat_zero(H);
+                _perm_clear(P);
+                _perm_clear(pivots);
+                return;
+            }
+            continue;
         }
 
-        fmpz_clear(d2);
-        fmpz_clear(d1);
-    }
-
-    if (!fmpz_is_zero(g))       /* chosen matrix invertible */
-    {
-        fmpz_mat_init(H1, r - 1, r - 1);
-
-        if (COEFF_IS_MPZ(*g) && C->r > 3)   /* if g is too big, call another algorithm */
+        /* if A has full column rank we might wish to use minors based hnf */
+        if (r == n && n < 52)
         {
-            fmpz_mat_hnf(H1, C);
-        }  else                    /* use modulo determinant algorithm to compute HNF of C */
-            fmpz_mat_hnf_modular(H1, C, g);
+            slong b = fmpz_mat_max_bits(A), cutoff = 52;
+            if (b < 0)
+                b = -b;
 
-        fmpz_mat_clear(B);
-        fmpz_mat_init(B, r - 1, n);
+            if (b <= 8)
+                cutoff = 35;
+            else if (b <= 32)
+                cutoff = 44;
+            else if (b <= 256)
+                cutoff = 48;
 
-        for (j = 0; j < n; j++)
+            if (n < cutoff)
+            {
+                fmpz_mat_hnf_minors(H, A);
+                _perm_clear(P);
+                _perm_clear(pivots);
+                return;
+            }
+        }
+
+        fmpz_mat_init(c, 1, r - 1);
+        fmpz_mat_init(d, 1, r - 1);
+        fmpz_mat_init(B, FLINT_MAX(r - 2, 0), r - 1);
+        fmpz_mat_init(C, r - 1, r - 1);
+
+        for (i = 0; i < r - 2; i++)
         {
-            for (i = 0; i < r - 2; i++)
+            for (j = 0; j < r - 1; j++)
+            {
                 fmpz_set(fmpz_mat_entry(B, i, j),
-                         fmpz_mat_entry(A, P[i], pivots[j]));
-            fmpz_mul(fmpz_mat_entry(B, r - 2, j), s,
-                     fmpz_mat_entry(A, P[r - 2], pivots[j]));
-            fmpz_addmul(fmpz_mat_entry(B, r - 2, j), t,
-                        fmpz_mat_entry(A, P[r - 1], pivots[j]));
+                        fmpz_mat_entry(A, P[i], pivots[j]));
+                fmpz_set(fmpz_mat_entry(C, i, j),
+                        fmpz_mat_entry(A, P[i], pivots[j]));
+            }
+            fmpz_set(fmpz_mat_entry(C, i, r - 1),
+                    fmpz_mat_entry(A, P[i], pivots[r - 1]));
+        }
+        for (j = 0; j < r - 1; j++)
+        {
+            fmpz_set(fmpz_mat_entry(c, 0, j),
+                    fmpz_mat_entry(A, P[r - 2], pivots[j]));
+            fmpz_set(fmpz_mat_entry(d, 0, j),
+                    fmpz_mat_entry(A, P[r - 1], pivots[j]));
         }
 
-        fmpz_mat_init(H2, r - 1, n);
-        fmpz_mat_init(H3, m + 1, n);
+        fmpz_init(g);
+        fmpz_init(s);
+        fmpz_init(t);
 
-        add_columns(H2, B, H1);
+        /* if rank is too low leave g = 0 so we don't try to decompose later */
+        if (r > 2)
+        {
+            fmpz_init(d1);
+            fmpz_init(d2);
+
+            double_det(d1, d2, B, c, d);
+            fmpz_xgcd(g, s, t, d1, d2);
+
+            for (j = 0; j < r - 1; j++)
+            {
+                fmpz_mul(fmpz_mat_entry(C, r - 2, j), s,
+                        fmpz_mat_entry(A, P[r - 2], pivots[j]));
+                fmpz_addmul(fmpz_mat_entry(C, r - 2, j), t,
+                        fmpz_mat_entry(A, P[r - 1], pivots[j]));
+            }
+
+            fmpz_clear(d2);
+            fmpz_clear(d1);
+        }
+
+        if (!fmpz_is_zero(g))       /* chosen matrix invertible */
+        {
+            fmpz_mat_init(H1, r - 1, r - 1);
+
+            if (COEFF_IS_MPZ(*g) && C->r > 3)   /* if g is too big, recurse */
+                fmpz_mat_hnf_pernet_stein(H1, C, state);
+            else                    /* use modulo determinant algorithm to compute HNF of C */
+                fmpz_mat_hnf_modular(H1, C, g);
+
+            fmpz_mat_clear(B);
+            fmpz_mat_init(B, r - 1, n);
 
-        for (i = 0; i < r - 1; i++)
             for (j = 0; j < n; j++)
-                fmpz_set(fmpz_mat_entry(H3, i, pivots[j]),
-                         fmpz_mat_entry(H2, i, j));
+            {
+                for (i = 0; i < r - 2; i++)
+                    fmpz_set(fmpz_mat_entry(B, i, j),
+                            fmpz_mat_entry(A, P[i], pivots[j]));
+                fmpz_mul(fmpz_mat_entry(B, r - 2, j), s,
+                        fmpz_mat_entry(A, P[r - 2], pivots[j]));
+                fmpz_addmul(fmpz_mat_entry(B, r - 2, j), t,
+                        fmpz_mat_entry(A, P[r - 1], pivots[j]));
+            }
 
-        for (i = 1; i <= m - r + 2; i++)
-            for (j = 0; j < n; j++)
-                fmpz_set(fmpz_mat_entry(H3, H3->r - i, j),
-                         fmpz_mat_entry(A, P[m - i], j));
+            fmpz_mat_init(H2, r - 1, n);
+            fmpz_mat_init(H3, m + 1, n);
 
-        add_rows(H3, r - 1);
+            add_columns(H2, B, H1, state);
 
-        /* fill H with HNF */
-        for (i = 0; i < m; i++)
-            for (j = 0; j < n; j++)
-                fmpz_set(fmpz_mat_entry(H, i, j), fmpz_mat_entry(H3, i, j));
+            for (i = 0; i < r - 1; i++)
+                for (j = 0; j < n; j++)
+                    fmpz_set(fmpz_mat_entry(H3, i, pivots[j]),
+                            fmpz_mat_entry(H2, i, j));
 
-        fmpz_mat_clear(H1);
-        fmpz_mat_clear(H2);
-        fmpz_mat_clear(H3);
-    }
-    else
-    {
-        if (r == n)             /* if A has full column rank we can use minors based hnf */
-            fmpz_mat_hnf_minors(H, A);
+            for (i = 1; i <= m - r + 2; i++)
+                for (j = 0; j < n; j++)
+                    fmpz_set(fmpz_mat_entry(H3, H3->r - i, j),
+                            fmpz_mat_entry(A, P[m - i], j));
+
+            /* check the pivots of H3 are as expected */
+            for (i = 0; i < r - 1; i++)
+            {
+                for (j = 0; j < H3->c && fmpz_is_zero(fmpz_mat_entry(H3, i, j)); j++);
+                if (pivots[i] != j)
+                    break;
+            }
+
+            /* the pivots were as expected so our choice of prime was ok */
+            if (i == r - 1)
+            {
+                /* add final rows in */
+                add_rows(H3, r - 1, pivots, r - 1);
+
+                /* fill H with HNF */
+                for (i = 0; i < m; i++)
+                    for (j = 0; j < n; j++)
+                        fmpz_set(fmpz_mat_entry(H, i, j), fmpz_mat_entry(H3, i, j));
+
+                finished = 1;
+            }
+            /* otherwise we must restart as our random prime gave us incorrect pivots */
+
+            fmpz_mat_clear(H1);
+            fmpz_mat_clear(H2);
+            fmpz_mat_clear(H3);
+        }
         else
-            fmpz_mat_hnf_classical(H, A);
+        {
+            if (r == n)             /* if A has full column rank we can use minors based hnf */
+                fmpz_mat_hnf_minors(H, A);
+            else
+                fmpz_mat_hnf_classical(H, A);
+            finished = 1;
+        }
+
+        fmpz_clear(t);
+        fmpz_clear(s);
+        fmpz_clear(g);
+        fmpz_mat_clear(C);
+        fmpz_mat_clear(B);
+        fmpz_mat_clear(c);
+        fmpz_mat_clear(d);
     }
 
     _perm_clear(P);
     _perm_clear(pivots);
-    fmpz_clear(t);
-    fmpz_clear(s);
-    fmpz_clear(g);
-    fmpz_mat_clear(C);
-    fmpz_mat_clear(B);
-    fmpz_mat_clear(c);
-    fmpz_mat_clear(d);
-
-    return 1;
 }
+
