@@ -1,31 +1,18 @@
-/*=============================================================================
+/*
+    Copyright (C) 2011 Andy Novocin
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2011 Andy Novocin
-
-******************************************************************************/
-
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <sys/types.h>
+#if (!defined (__WIN32) || defined(__CYGWIN__)) && !defined(_MSC_VER) 
 #include <unistd.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <gmp.h>
@@ -111,6 +98,9 @@ int main(void)
             }
 
             fclose(out);
+            for (i = 0; i < k; ++i)
+                fmpz_mat_clear(M[i]);
+            flint_free(M);
             exit(0);
         }
         else  /* Parent process */
