@@ -1,28 +1,14 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2011 Sebastian Pancratz
     Copyright (C) 2014 William Hart
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #ifndef FMPZ_MOD_POLY_H
 #define FMPZ_MOD_POLY_H
@@ -44,6 +30,7 @@
 #include "fmpz.h"
 #include "fmpz_poly.h"
 #include "fmpz_mat.h"
+#include "fmpz_mod_mat.h"
 
 #ifdef __cplusplus
  extern "C" {
@@ -95,20 +82,20 @@ typedef fmpz_mod_poly_frobenius_powers_struct fmpz_mod_poly_frobenius_powers_t[1
 
 typedef struct
 {
-    fmpz_mat_struct A;
-    fmpz_mod_poly_struct poly1;
-    fmpz_mod_poly_struct poly2;
-    fmpz_mod_poly_struct poly2inv;
+    fmpz_mat_struct * A;
+    fmpz_mod_poly_struct * poly1;
+    fmpz_mod_poly_struct * poly2;
+    fmpz_mod_poly_struct * poly2inv;
 }
 fmpz_mod_poly_matrix_precompute_arg_t;
 
 typedef struct
 {
-    fmpz_mat_struct A;
-    fmpz_mod_poly_struct res;
-    fmpz_mod_poly_struct poly1;
-    fmpz_mod_poly_struct poly3;
-    fmpz_mod_poly_struct poly3inv;
+    fmpz_mat_struct * A;
+    fmpz_mod_poly_struct * res;
+    fmpz_mod_poly_struct * poly1;
+    fmpz_mod_poly_struct * poly3;
+    fmpz_mod_poly_struct * poly3inv;
 }
 fmpz_mod_poly_compose_mod_precomp_preinv_arg_t;
 
@@ -173,6 +160,9 @@ FLINT_DLL void fmpz_mod_poly_randtest_monic(fmpz_mod_poly_t f, flint_rand_t stat
 FLINT_DLL void fmpz_mod_poly_randtest_monic_irreducible(fmpz_mod_poly_t f,
                                          flint_rand_t state, slong len);
 
+FLINT_DLL void fmpz_mod_poly_randtest_monic_primitive(fmpz_mod_poly_t f,
+                                         flint_rand_t state, slong len);
+
 FLINT_DLL void fmpz_mod_poly_randtest_trinomial(fmpz_mod_poly_t f, flint_rand_t state, slong len);
 
 FLINT_DLL int fmpz_mod_poly_randtest_trinomial_irreducible(fmpz_mod_poly_t f,
@@ -220,11 +210,14 @@ int fmpz_mod_poly_is_one(const fmpz_mod_poly_t poly)
 }
 
 FMPZ_MOD_POLY_INLINE
-int fmpz_mod_poly_is_x(const fmpz_mod_poly_t op)
+int fmpz_mod_poly_is_gen(const fmpz_mod_poly_t op)
 {
     return (op->length) == 2 && (*(op->coeffs + 1) == WORD(1)) && (*(op->coeffs + 0) == WORD(0));
 }
 
+/* Deprecated */
+#define fmpz_mod_poly_is_x fmpz_mod_poly_is_gen
+
 /*  Assignment and basic manipulation ****************************************/
 
 FLINT_DLL void fmpz_mod_poly_set(fmpz_mod_poly_t poly1, const fmpz_mod_poly_t poly2);
@@ -241,6 +234,20 @@ void fmpz_mod_poly_zero(fmpz_mod_poly_t poly)
    _fmpz_mod_poly_set_length(poly, 0);
 }
 
+FMPZ_MOD_POLY_INLINE
+void fmpz_mod_poly_one(fmpz_mod_poly_t poly)
+{
+   if (fmpz_is_one(&poly->p))
+   {
+      _fmpz_mod_poly_set_length(poly, 0);
+   } else
+   {
+      fmpz_mod_poly_fit_length(poly, 1);
+      _fmpz_mod_poly_set_length(poly, 1);
+      fmpz_set_ui(poly->coeffs + 0, 1);
+   }
+}
+
 FLINT_DLL void fmpz_mod_poly_zero_coeffs(fmpz_mod_poly_t poly, slong i, slong j);
 
 /*  Conversion ***************************************************************/
@@ -298,6 +305,8 @@ FLINT_DLL void fmpz_mod_poly_set_coeff_fmpz(fmpz_mod_poly_t poly, slong n, const
 
 FLINT_DLL void fmpz_mod_poly_set_coeff_ui(fmpz_mod_poly_t poly, slong n, ulong x);
 
+FLINT_DLL void fmpz_mod_poly_set_coeff_si(fmpz_mod_poly_t poly, slong n, slong x);
+
 FMPZ_MOD_POLY_INLINE 
 void fmpz_mod_poly_get_coeff_fmpz(fmpz_t x, const fmpz_mod_poly_t poly, slong n)
 {
@@ -375,6 +384,12 @@ FLINT_DLL void _fmpz_mod_poly_scalar_mul_fmpz(fmpz *res, const fmpz *poly, slong
 FLINT_DLL void fmpz_mod_poly_scalar_mul_fmpz(fmpz_mod_poly_t res, 
     const fmpz_mod_poly_t poly, const fmpz_t x);
 
+FLINT_DLL void _fmpz_mod_poly_scalar_mul_ui(fmpz *res, const fmpz *poly, slong len, 
+                                    ulong x, const fmpz_t p);
+
+FLINT_DLL void fmpz_mod_poly_scalar_mul_ui(fmpz_mod_poly_t res, 
+    const fmpz_mod_poly_t poly, ulong x);
+
 /*  Scalar division ****************************************************/
 
 FLINT_DLL void _fmpz_mod_poly_scalar_div_fmpz(fmpz *res, const fmpz *poly, slong len, 
@@ -475,6 +490,21 @@ FLINT_DLL void _fmpz_mod_poly_powmod_x_fmpz_preinv(fmpz * res, const fmpz_t e, c
 FLINT_DLL void fmpz_mod_poly_powmod_x_fmpz_preinv(fmpz_mod_poly_t res, const fmpz_t e,
                           const fmpz_mod_poly_t f, const fmpz_mod_poly_t finv);
 
+FLINT_DLL void _fmpz_mod_poly_powers_mod_preinv_naive(fmpz ** res,
+                    const fmpz * f, slong flen, slong n, const fmpz * g,
+                 slong glen, const fmpz * ginv, slong ginvlen, const fmpz_t p);
+ 
+FLINT_DLL void fmpz_mod_poly_powers_mod_naive(fmpz_mod_poly_struct * res,
+                    const fmpz_mod_poly_t f, slong n, const fmpz_mod_poly_t g);
+
+FLINT_DLL void _fmpz_mod_poly_powers_mod_preinv_threaded_pool(fmpz ** res,
+       const fmpz * f, slong flen, slong n, const fmpz * g, slong glen,
+                          const fmpz * ginv, slong ginvlen, const fmpz_t p,
+	                      thread_pool_handle * threads, slong num_threads);
+
+FLINT_DLL void fmpz_mod_poly_powers_mod_bsgs(fmpz_mod_poly_struct * res,
+                    const fmpz_mod_poly_t f, slong n, const fmpz_mod_poly_t g);
+
 FLINT_DLL void fmpz_mod_poly_frobenius_powers_2exp_precomp(fmpz_mod_poly_frobenius_powers_2exp_t pow, 
                  const fmpz_mod_poly_t f, const fmpz_mod_poly_t finv, ulong m);
 
@@ -546,7 +576,10 @@ void _fmpz_mod_poly_divrem(fmpz *Q, fmpz *R,
                            const fmpz *A, slong lenA, const fmpz *B, slong lenB, 
                            const fmpz_t invB, const fmpz_t p)
 {
-    _fmpz_mod_poly_divrem_divconquer(Q, R, A, lenA, B, lenB, invB, p);
+    if (lenB < 8)
+	   _fmpz_mod_poly_divrem_basecase(Q, R, A, lenA, B, lenB, invB, p);
+	else
+	   _fmpz_mod_poly_divrem_divconquer(Q, R, A, lenA, B, lenB, invB, p);
 }
 
 FMPZ_MOD_POLY_INLINE 
@@ -585,8 +618,8 @@ void _fmpz_mod_poly_rem(fmpz *R,
     _fmpz_vec_clear(Q, lenA - lenB + 1);
 }
 
-FMPZ_MOD_POLY_INLINE 
-void fmpz_mod_poly_rem(fmpz_mod_poly_t R, 
+FMPZ_MOD_POLY_INLINE
+void fmpz_mod_poly_rem(fmpz_mod_poly_t R,
                        const fmpz_mod_poly_t A, const fmpz_mod_poly_t B)
 {
     fmpz_mod_poly_t Q;
@@ -596,8 +629,8 @@ void fmpz_mod_poly_rem(fmpz_mod_poly_t R,
     fmpz_mod_poly_clear(Q);
 }
 
-FMPZ_MOD_POLY_INLINE 
-void fmpz_mod_poly_rem_f(fmpz_t f, fmpz_mod_poly_t R, 
+FMPZ_MOD_POLY_INLINE
+void fmpz_mod_poly_rem_f(fmpz_t f, fmpz_mod_poly_t R,
                        const fmpz_mod_poly_t A, const fmpz_mod_poly_t B)
 {
     fmpz_mod_poly_t Q;
@@ -799,6 +832,20 @@ fmpz_mod_poly_xgcd_f(fmpz_t f, fmpz_mod_poly_t G, fmpz_mod_poly_t S, fmpz_mod_po
     fmpz_mod_poly_xgcd_euclidean_f(f, G, S, T, A, B);
 }
 
+FLINT_DLL slong _fmpz_mod_poly_gcdinv_euclidean_f(fmpz_t f, fmpz *G, fmpz *S, 
+                    const fmpz *A, slong lenA, const fmpz *B, slong lenB, 
+                                            const fmpz_t invA, const fmpz_t p);
+
+FLINT_DLL void fmpz_mod_poly_gcdinv_euclidean_f(fmpz_t f, fmpz_mod_poly_t G, 
+          fmpz_mod_poly_t S, const fmpz_mod_poly_t A, const fmpz_mod_poly_t B);
+							 
+FLINT_DLL slong _fmpz_mod_poly_gcdinv_euclidean(fmpz *G, fmpz *S, 
+                  const fmpz *A, slong lenA, const fmpz *B, slong lenB, 
+                                            const fmpz_t invA, const fmpz_t p);
+
+FLINT_DLL void fmpz_mod_poly_gcdinv_euclidean(fmpz_mod_poly_t G, 
+          fmpz_mod_poly_t S, const fmpz_mod_poly_t A, const fmpz_mod_poly_t B);
+
 FLINT_DLL slong _fmpz_mod_poly_gcdinv(fmpz *G, fmpz *S, 
                            const fmpz *A, slong lenA, const fmpz *B, slong lenB, 
                            const fmpz_t p);
@@ -827,6 +874,45 @@ FLINT_DLL int fmpz_mod_poly_invmod(fmpz_mod_poly_t A,
 FLINT_DLL int fmpz_mod_poly_invmod_f(fmpz_t f, fmpz_mod_poly_t A, 
                          const fmpz_mod_poly_t B, const fmpz_mod_poly_t P);
 
+/*  Minpoly  *****************************************************************/
+
+FLINT_DLL slong _fmpz_mod_poly_minpoly_bm(fmpz* poly, 
+                 const fmpz* seq, slong len, const fmpz_t p);
+
+FMPZ_MOD_POLY_INLINE void 
+fmpz_mod_poly_minpoly_bm(fmpz_mod_poly_t poly, const fmpz* seq, slong len)
+{
+    fmpz_mod_poly_fit_length(poly, len+1);
+    poly->length = _fmpz_mod_poly_minpoly_bm(poly->coeffs, seq, len, &poly->p);
+}
+
+FLINT_DLL slong _fmpz_mod_poly_minpoly_hgcd(fmpz* poly, 
+                 const fmpz* seq, slong len, const fmpz_t p);
+
+FMPZ_MOD_POLY_INLINE void 
+fmpz_mod_poly_minpoly_hgcd(fmpz_mod_poly_t poly, const fmpz* seq, slong len)
+{
+    fmpz_mod_poly_fit_length(poly, len+1);
+    poly->length = _fmpz_mod_poly_minpoly_hgcd(poly->coeffs, seq, len, &poly->p);
+}
+
+FMPZ_MOD_POLY_INLINE slong 
+_fmpz_mod_poly_minpoly(fmpz* poly, const fmpz* seq, slong len, const fmpz_t p)
+{
+    if (len < FLINT_MAX(200, 530-22*fmpz_size(p))) 
+    {
+        return _fmpz_mod_poly_minpoly_bm(poly, seq, len, p);
+    }
+    else return _fmpz_mod_poly_minpoly_hgcd(poly, seq, len, p);
+}
+
+FMPZ_MOD_POLY_INLINE void 
+fmpz_mod_poly_minpoly(fmpz_mod_poly_t poly, const fmpz* seq, slong len)
+{
+    fmpz_mod_poly_fit_length(poly, len+1);
+    poly->length = _fmpz_mod_poly_minpoly(poly->coeffs, seq, len, &poly->p);
+}
+
 /*  Resultant  ***************************************************************/
 
 FLINT_DLL void _fmpz_mod_poly_resultant_euclidean(fmpz_t res, 
@@ -970,7 +1056,7 @@ FLINT_DLL void _fmpz_mod_poly_precompute_matrix (fmpz_mat_t A, const fmpz * poly
                           const fmpz * poly2, slong len2, const fmpz * poly2inv,
                           slong len2inv, const fmpz_t p);
 
-FLINT_DLL void * _fmpz_mod_poly_precompute_matrix_worker(void * arg_ptr);
+FLINT_DLL void _fmpz_mod_poly_precompute_matrix_worker(void * arg_ptr);
 
 FLINT_DLL void fmpz_mod_poly_precompute_matrix(fmpz_mat_t A, const fmpz_mod_poly_t poly1,
                    const fmpz_mod_poly_t poly2, const fmpz_mod_poly_t poly2inv);
@@ -979,7 +1065,7 @@ FLINT_DLL void _fmpz_mod_poly_compose_mod_brent_kung_precomp_preinv(fmpz * res,
          const fmpz * poly1, slong len1, const fmpz_mat_t A, const fmpz * poly3,
          slong len3, const fmpz * poly3inv, slong len3inv, const fmpz_t p);
 
-FLINT_DLL void * _fmpz_mod_poly_compose_mod_brent_kung_precomp_preinv_worker(void * arg_ptr);
+FLINT_DLL void _fmpz_mod_poly_compose_mod_brent_kung_precomp_preinv_worker(void * arg_ptr);
 
 FLINT_DLL void fmpz_mod_poly_compose_mod_brent_kung_precomp_preinv(fmpz_mod_poly_t res,
                    const fmpz_mod_poly_t poly1, const fmpz_mat_t A,
@@ -1001,27 +1087,33 @@ FLINT_DLL void fmpz_mod_poly_compose_mod_horner(fmpz_mod_poly_t res, const fmpz_
 
 FLINT_DLL void _fmpz_mod_poly_compose_mod_brent_kung_vec_preinv(fmpz_mod_poly_struct * res,
                  const fmpz_mod_poly_struct * polys, slong len1, slong l,
-                 const fmpz * poly, slong len, const fmpz * polyinv,
-                 slong leninv, const fmpz_t p);
+                 const fmpz * g, slong glen, const fmpz * poly, slong len,
+		 const fmpz * polyinv, slong leninv, const fmpz_t p);
 
 FLINT_DLL void fmpz_mod_poly_compose_mod_brent_kung_vec_preinv(fmpz_mod_poly_struct * res,
+                    const fmpz_mod_poly_struct * polys, slong len1,
+                    slong n, const fmpz_mod_poly_t g,
+		    const fmpz_mod_poly_t poly,
+		    const fmpz_mod_poly_t polyinv);
+
+FLINT_DLL void _fmpz_mod_poly_compose_mod_brent_kung_vec_preinv_threaded_pool(fmpz_mod_poly_struct * res,
+             const fmpz_mod_poly_struct * polys, slong lenpolys, slong l,
+             const fmpz * g, slong glen, const fmpz * poly, slong len,
+             const fmpz * polyinv, slong leninv, const fmpz_t p,
+                              thread_pool_handle * threads, slong num_threads);
+
+FLINT_DLL void fmpz_mod_poly_compose_mod_brent_kung_vec_preinv_threaded_pool(fmpz_mod_poly_struct * res,
+            const fmpz_mod_poly_struct * polys, slong len1, slong n,
+            const fmpz_mod_poly_t g, const fmpz_mod_poly_t poly,
+            const fmpz_mod_poly_t polyinv, thread_pool_handle * threads,
+                                                            slong num_threads);
+
+FLINT_DLL void
+fmpz_mod_poly_compose_mod_brent_kung_vec_preinv_threaded(fmpz_mod_poly_struct * res,
                     const fmpz_mod_poly_struct * polys, slong len1, slong n,
-                    const fmpz_mod_poly_t poly, const fmpz_mod_poly_t polyinv);
-
-FLINT_DLL void _fmpz_mod_poly_compose_mod_brent_kung_vec_preinv_threaded(fmpz_mod_poly_struct * res,
-                                                 const fmpz_mod_poly_struct *
-                                                 polys, slong lenpolys,
-                                                 slong l, const fmpz * poly,
-                                                 slong len,
-                                                 const fmpz * polyinv,
-                                                 slong leninv, const fmpz_t p);
-
-FLINT_DLL void fmpz_mod_poly_compose_mod_brent_kung_vec_preinv_threaded(fmpz_mod_poly_struct * res,
-                                                const fmpz_mod_poly_struct *
-                                                polys, slong len1, slong n,
-                                                const fmpz_mod_poly_t poly,
+                    const fmpz_mod_poly_t g, const fmpz_mod_poly_t poly,
                                                 const fmpz_mod_poly_t polyinv);
-
+ 
 /*  Radix conversion *********************************************************/
 
 typedef struct {
@@ -1085,6 +1177,106 @@ int fmpz_mod_poly_print_pretty(const fmpz_mod_poly_t poly, const char * x)
     return fmpz_mod_poly_fprint_pretty(stdout, poly, x);
 }
 
+/* Products *****************************************************************/
+
+FLINT_DLL void _fmpz_mod_poly_product_roots_fmpz_vec(fmpz * poly, const fmpz * xs,
+                                                     slong n, const fmpz_t mod);
+
+FLINT_DLL void fmpz_mod_poly_product_roots_fmpz_vec(fmpz_poly_t poly, const fmpz * xs,
+                                                    slong n, const fmpz_t mod);
+
+FLINT_DLL int fmpz_mod_poly_find_distinct_nonzero_roots(fmpz * roots,
+                                                      const fmpz_mod_poly_t P);
+
+FLINT_DLL void _fmpz_mod_poly_split_rabin(fmpz_mod_poly_t a, fmpz_mod_poly_t b,
+                                   const fmpz_mod_poly_t f, const fmpz_t halfp,
+                fmpz_mod_poly_t t, fmpz_mod_poly_t t2, flint_rand_t randstate);
+
+
+/* Berlekamp-Massey Algorithm - see fmpz_mod_poly/berlekamp_massey.c for more info ********/
+typedef struct {
+    slong npoints;
+    fmpz_mod_poly_t R0, R1;
+    fmpz_mod_poly_t V0, V1;
+    fmpz_mod_poly_t qt, rt;
+    fmpz_mod_poly_t points;
+} fmpz_mod_berlekamp_massey_struct;
+typedef fmpz_mod_berlekamp_massey_struct fmpz_mod_berlekamp_massey_t[1];
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_init(
+                        fmpz_mod_berlekamp_massey_t B,
+                        const fmpz_t p);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_init_ui(
+                        fmpz_mod_berlekamp_massey_t B,
+                        ulong p);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_start_over(
+                        fmpz_mod_berlekamp_massey_t B);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_clear(
+                        fmpz_mod_berlekamp_massey_t B);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_set_prime(
+                        fmpz_mod_berlekamp_massey_t B,
+                        const fmpz_t p);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_print(
+                        const fmpz_mod_berlekamp_massey_t B);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_add_points(
+                        fmpz_mod_berlekamp_massey_t B,
+                        const fmpz * a,
+                        slong count);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_add_zeros(
+                        fmpz_mod_berlekamp_massey_t B,
+                        slong count);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_add_point(
+                        fmpz_mod_berlekamp_massey_t B,
+                        const fmpz_t a);
+
+FLINT_DLL void fmpz_mod_berlekamp_massey_add_point_ui(
+                        fmpz_mod_berlekamp_massey_t B,
+                        ulong a);
+
+FLINT_DLL int fmpz_mod_berlekamp_massey_reduce(
+                        fmpz_mod_berlekamp_massey_t B);
+
+FMPZ_MOD_POLY_INLINE const fmpz * fmpz_mod_berlekamp_massey_points(
+                        const fmpz_mod_berlekamp_massey_t B)
+{
+    return B->points->coeffs;
+}
+
+FMPZ_MOD_POLY_INLINE slong fmpz_mod_berlekamp_massey_point_count(
+                        const fmpz_mod_berlekamp_massey_t B)
+{
+    return B->points->length;
+}
+
+FMPZ_MOD_POLY_INLINE const fmpz_mod_poly_struct * fmpz_mod_berlekamp_massey_V_poly(
+                        const fmpz_mod_berlekamp_massey_t B)
+{
+    return B->V1;
+}
+
+FMPZ_MOD_POLY_INLINE const fmpz_mod_poly_struct * fmpz_mod_berlekamp_massey_R_poly(
+                        const fmpz_mod_berlekamp_massey_t B)
+{
+    return B->R1;
+}
+
+/* Inlines *******************************************************************/
+
+FLINT_DLL void fmpz_mod_poly_add_si(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly, slong c);
+FLINT_DLL void fmpz_mod_poly_sub_si(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly, slong c);
+FLINT_DLL void fmpz_mod_poly_si_sub(fmpz_mod_poly_t res, slong c, const fmpz_mod_poly_t poly);
+FLINT_DLL void fmpz_mod_poly_add_fmpz(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly, fmpz_t c);
+FLINT_DLL void fmpz_mod_poly_sub_fmpz(fmpz_mod_poly_t res, const fmpz_mod_poly_t poly, fmpz_t c);
+FLINT_DLL void fmpz_mod_poly_fmpz_sub(fmpz_mod_poly_t res, fmpz_t c, const fmpz_mod_poly_t poly);
+
 #ifdef __cplusplus
 }
 #endif
