@@ -1,31 +1,17 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2010 Sebastian Pancratz
     Copyright (C) 2010 William Hart
     Copyright (C) 2011 Fredrik Johansson
     Copyright (C) 2012 Lina Kulakova
     Copyright (C) 2013 Martin Lee
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #undef ulong
 #define ulong ulongxx/* interferes with system includes */
@@ -61,13 +47,11 @@ _fmpz_mod_poly_powmod_x_fmpz_preinv(fmpz * res, const fmpz_t e, const fmpz * f,
     fmpz_one(res);
     _fmpz_vec_zero(res + 1, lenf - 2);
     l = z_sizeinbase(lenf - 1, 2) - 2;
-    window = WORD(0);
     window = (WORD(1) << l);
     c = l;
     i = fmpz_sizeinbase(e, 2) - 2;
     if (i <= l)
     {
-      window = WORD(0);
       window = (WORD(1) << i);
       c = i;
       l = i;
@@ -125,14 +109,14 @@ fmpz_mod_poly_powmod_x_fmpz_preinv(fmpz_mod_poly_t res, const fmpz_t e,
     {
         flint_printf("Exception (fmpz_mod_poly_powmod_x_fmpz_preinv)."
                      "Divide by zero\n");
-        abort();
+        flint_abort();
     }
 
     if (fmpz_sgn(e) < 0)
     {
         flint_printf("Exception (fmpz_mod_poly_powmod_x_fmpz_preinv)."
                      "Negative exp not implemented\n");
-        abort();
+        flint_abort();
     }
 
     if (lenf == 1)
