@@ -1,30 +1,17 @@
-/*=============================================================================
+/*
+    Copyright (C) 2012 Lina Kulakova
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2012 Lina Kulakova
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <math.h>
 #include "fmpz_mod_poly.h"
+#include "thread_support.h"
 
 void
 fmpz_mod_poly_factor_kaltofen_shoup(fmpz_mod_poly_factor_t res,
@@ -50,7 +37,7 @@ fmpz_mod_poly_factor_kaltofen_shoup(fmpz_mod_poly_factor_t res,
     {
         flint_printf("Exception (fmpz_mod_poly_factor_kaltofen_shoup): \n");
         flint_printf("Not enough memory.\n");
-        abort();
+        flint_abort();
     }
 
     /* compute squarefree factorisation */
@@ -66,8 +53,8 @@ fmpz_mod_poly_factor_kaltofen_shoup(fmpz_mod_poly_factor_t res,
         if ((flint_get_num_threads() > 1) &&
             ((sq_free->poly + i)->length > (1024*flint_get_num_threads())/4))
             fmpz_mod_poly_factor_distinct_deg_threaded(dist_deg,
-                                                       sq_free->poly + i,
-                                                       &degs);
+                                                   sq_free->poly + i,
+                                                   &degs);
         else
             fmpz_mod_poly_factor_distinct_deg(dist_deg, sq_free->poly + i,
                                               &degs);
