@@ -1,28 +1,15 @@
-/*=============================================================================
+/*
+    Copyright (C) 2012 Lina Kulakova
+    Copyright (C) 2013, 2014 Martin Lee
+    Copyright (C) 2020 William Hart
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2012 Lina Kulakova
-    Copyright (C) 2013, 2014 Martin Lee
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #undef ulong
 #define ulong ulongxx/* interferes with system includes */
@@ -72,17 +59,13 @@ int fmpz_mod_poly_is_irreducible_ddf(const fmpz_mod_poly_t poly)
     {
         flint_printf("Exception (fmpz_mod_poly_is_irreducible_ddf): \n");
         flint_printf("Not enough memory.\n");
-        abort();
+        flint_abort();
     }
     H = h + (l + 1);
     I = H + m;
-    fmpz_mod_poly_init(h[0], p);
-    fmpz_mod_poly_init(h[1], p);
-    for (i = 0; i < m; i++)
-    {
-        fmpz_mod_poly_init(H[i], p);
-        fmpz_mod_poly_init(I[i], p);
-    }
+
+    for (i = 0; i < 2*m + l + 1; i++)
+        fmpz_mod_poly_init(h[i], p);
 
     fmpz_mod_poly_make_monic(v, poly);
 
@@ -98,14 +81,16 @@ int fmpz_mod_poly_is_irreducible_ddf(const fmpz_mod_poly_t poly)
                                                              (1 << (i - 1))),
                                                              *(h + 1),
                                                              (1 << (i - 1)),
-                                                             (1 << (i - 1)), v,
-                                                             vinv);
+                                                             (1 << (i - 1)),
+                                                             *(h + (1 << (i - 1))),
+                                                             v, vinv);
         fmpz_mod_poly_compose_mod_brent_kung_vec_preinv (*(h + 1 +
                                                          (1 << (i - 1))),
                                                          *(h + 1),
                                                          (1 << (i - 1)),
-                                                         l - (1 << (i - 1)), v,
-                                                         vinv);
+                                                         l - (1 << (i - 1)),
+                                                         *(h + (1 << (i - 1))),
+                                                         v, vinv);
     }
     else
     {
