@@ -1,42 +1,33 @@
-/*=============================================================================
+/*
+    Copyright (C) 2008-2011 William Hart
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2008-2011 William Hart
-    
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <stdlib.h>
 #include "fmpz_poly.h"
 #include "fft.h"
 #include "fft_tuning.h"
+#include "flint.h"
 
 void _fmpz_poly_mullow_SS(fmpz * output, const fmpz * input1, slong len1, 
                const fmpz * input2, slong len2, slong trunc)
 {
     slong len_out, loglen, loglen2, n;
     slong output_bits, limbs, size, i;
-    mp_limb_t * ptr, * t1, * t2, * tt, * s1, ** ii, ** jj;
+    mp_limb_t * ptr, ** t1, ** t2, ** tt, ** s1, ** ii, ** jj;
     slong bits1, bits2;
     ulong size1, size2;
     int sign = 0;
+    int N;
+    TMP_INIT;
+
+    TMP_START;
 
     len1 = FLINT_MIN(len1, trunc);
     len2 = FLINT_MIN(len2, trunc);
@@ -61,13 +52,28 @@ void _fmpz_poly_mullow_SS(fmpz * output, const fmpz * input1, slong len1,
     size = limbs + 1;
 
     /* allocate space for ffts */
-    ii = flint_malloc((4*(n + n*size) + 5*size)*sizeof(mp_limb_t));
+
+    N = flint_get_num_threads();
+    ii = flint_malloc((4*(n + n*size) + 5*size*N)*sizeof(mp_limb_t));
     for (i = 0, ptr = (mp_limb_t *) ii + 4*n; i < 4*n; i++, ptr += size) 
         ii[i] = ptr;
-    t1 = ptr;
-    t2 = t1 + size;
-    s1 = t2 + size;
-    tt = s1 + size;
+   t1 = TMP_ALLOC(N*sizeof(mp_limb_t *));
+   t2 = TMP_ALLOC(N*sizeof(mp_limb_t *));
+   s1 = TMP_ALLOC(N*sizeof(mp_limb_t *));
+   tt = TMP_ALLOC(N*sizeof(mp_limb_t *));
+
+   t1[0] = ptr;
+   t2[0] = t1[0] + size*N;
+   s1[0] = t2[0] + size*N;
+   tt[0] = s1[0] + size*N;
+
+   for (i = 1; i < N; i++)
+   {
+      t1[i] = t1[i - 1] + size;
+      t2[i] = t2[i - 1] + size;
+      s1[i] = s1[i - 1] + size;
+      tt[i] = tt[i - 1] + 2*size;
+   }
 
     if (input1 != input2)
     {
@@ -105,13 +111,15 @@ void _fmpz_poly_mullow_SS(fmpz * output, const fmpz * input1, slong len1,
     limbs = (output_bits - 1) / FLINT_BITS + 1;
     limbs = fft_adjust_limbs(limbs); /* round up limbs for Nussbaumer */
     
-    fft_convolution(ii, jj, loglen - 2, limbs, len_out, &t1, &t2, &s1, tt); 
+    fft_convolution(ii, jj, loglen - 2, limbs, len_out, t1, t2, s1, tt); 
 
     _fmpz_vec_set_fft(output, trunc, ii, limbs, sign); /* write output */
 
     flint_free(ii); 
     if (input1 != input2) 
         flint_free(jj);
+
+    TMP_END;
 }
 
 void
