@@ -1,28 +1,14 @@
-/*=============================================================================
+/*
+    Copyright (C) 2010 Sebastian Pancratz
+    Copyright (C) 2011-2014 Fredrik Johansson
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-   Copyright (C) 2010 Sebastian Pancratz
-   Copyright (C) 2011-2014 Fredrik Johansson
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "fmpz_poly.h"
 
@@ -76,7 +62,7 @@ fmpz_poly_revert_series_newton(fmpz_poly_t Qinv, const fmpz_poly_t Q, slong n)
     {
         flint_printf("Exception (fmpz_poly_revert_series_newton). Input must have \n"
                "zero constant term and +1 or -1 as coefficient of x^1\n.");
-        abort();
+        flint_abort();
     }
 
     if (Qinv != Q)
