@@ -1,28 +1,14 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2007 William Hart and David Harvey
     Copyright (C) 2013 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -31,6 +17,10 @@
 #include <string.h>
 #include "profiler.h"
 
+#if (defined( _MSC_VER ) || (GMP_LIMB_BITS == 64 && defined (__amd64__)) || \
+	                    (GMP_LIMB_BITS == 32 && (defined (__i386__) || \
+			       defined (__i486__) || defined(__amd64__))))
+
 /*
    clock_last[i] is the last read clock value for clock #i.
    clock_accum[i] is the total time attributed to clock #i so far.
@@ -111,6 +101,8 @@ prof_repeat(double *min, double *max, profile_target_t target, void *arg)
         *max = max_time;
 }
 
+#endif
+
 void get_memory_usage(meminfo_t meminfo)
 {
     FILE * file = fopen("/proc/self/status", "r");
