@@ -1,27 +1,13 @@
-/*=============================================================================
+/*
+    Copyright (C) 2012 Sebastian Pancratz
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2012 Sebastian Pancratz
- 
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <assert.h>
 
@@ -116,7 +102,7 @@ static void _find_nonresidue(fmpz *rop,
     The value of \code{(rop,d)}$ is undefined when the return value 
     is zero.
  */
-int 
+FLINT_DLL int
 _artin_schreier_preimage(fmpz *rop, const fmpz *op, slong len, 
                          const fmpz *a, const slong *j, slong lena)
 {
