@@ -1,27 +1,13 @@
-/*=============================================================================
+/*
+    Copyright (C) 2012 Sebastian Pancratz
 
     This file is part of FLINT.
 
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
-    Copyright (C) 2012 Sebastian Pancratz
-
-******************************************************************************/
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -30,7 +16,7 @@
 #include "ulong_extras.h"
 #include "long_extras.h"
 
-extern int 
+FLINT_DLL extern int
 _artin_schreier_preimage(fmpz *rop, const fmpz *op, slong len, 
                          const fmpz *a, const slong *j, slong lena);
 
@@ -47,7 +33,7 @@ int main(void)
 /* PRIME p = 2 ***************************************************************/
 
     /* Check Artin Schreier preimages */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p = {WORD(2)};
         slong d;
@@ -99,7 +85,7 @@ int main(void)
     }
 
     /* Check aliasing: a = sqrt(a) */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p = {WORD(2)};
         slong d, N;
@@ -142,7 +128,7 @@ int main(void)
     }
 
     /* Test random squares over finite fields */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p = {WORD(2)};
         slong deg, N;
@@ -211,7 +197,7 @@ int main(void)
     }
 
     /* Test random elements over finite fields */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p = {WORD(2)};
         slong d, N;
@@ -266,7 +252,7 @@ int main(void)
     }
 
     /* Test random squares */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p = {WORD(2)};
         slong deg, N;
@@ -348,7 +334,7 @@ int main(void)
     }
 
     /* Test random elements */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p = {WORD(2)};
         slong d, N;
@@ -405,7 +391,7 @@ int main(void)
 /* PRIME p != 2 **************************************************************/
 
     /* Check aliasing: a = sqrt(a) */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p;
         slong d, N, q;
@@ -453,7 +439,7 @@ int main(void)
     }
 
     /* Test random squares over finite fields */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p;
         slong deg, N, q;
@@ -526,7 +512,7 @@ int main(void)
     }
 
     /* Test random elements over finite fields */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p;
         slong d, N, q;
@@ -586,7 +572,7 @@ int main(void)
     }
 
     /* Test random squares */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p;
         slong deg, N, q;
@@ -658,7 +644,7 @@ int main(void)
     }
 
     /* Test random elements */
-    for (i = 0; i < 2000; i++)
+    for (i = 0; i < 200 * flint_test_multiplier(); i++)
     {
         fmpz_t p;
         slong d, N, q;
